
//-------------------------------------------------------------------------------//
// Author: Stefan Lörwald, Universität Heidelberg                                //
// License: CC BY-NC 4.0 http://creativecommons.org/licenses/by-nc/4.0/legalcode //
//-------------------------------------------------------------------------------//

#pragma once

#include "maps.h"
#include "matrix.h"
#include "names.h"

namespace input
{
   namespace implementation
   {
      /// Checks the validity of a set of maps on a convex/conical hull description.
      void checkValidity(const ConvexHull<int>&, const ConicalHull<int>&, const Maps&);
      /// Checks the validity of a set of maps on an inequality description.
      void checkValidity(const Inequalities<int>&, const Maps&);
      /// Checks the validity of a set of inequalities.
      template <typename Integer>
      void checkValidity(const Matrix<Integer>&, const Inequalities<Integer>&);
      /// Checks the validity of a set of inequalities.
      void checkValidity(const ConvexHull<int>&, const ConicalHull<int>&, const Inequalities<int>&);
      /// Checks the validity of a polytope.
      void checkValidity(const ConvexHull<int>&, const ConicalHull<int>&, const Inequalities<int>&, const Maps&);
   }

   /// Returns true if the user provided the --check parameter
   bool checkValidity(int, char**);
}

#include "input_validity.eti"

